@@ -1,9 +1,12 @@
 import json
+import logging
 from typing import Tuple, Optional
 from django.contrib.auth.models import User
 from rest_framework.test import APIClient
 from rest_framework.authtoken.models import Token
 
+logger = logging.getLogger(__name__)
+
 
 class DefaultTestSetupMixin:
     user = None
@@ -11,6 +14,9 @@ class DefaultTestSetupMixin:
     api_client = None
     verbose = True
 
+    def __init__(self):
+        logger.warning('jutil.testing.DefaultTestSetupMixin is deprecated')
+
     def debug_print(self, *args, **kw):
         """
         print() only on verbose=True or self.verbose
