@@ -24,9 +24,8 @@ from django.test import TestCase
 from django.test.client import RequestFactory, Client
 from django.utils.translation import override, gettext as _, gettext_lazy
 from rest_framework.exceptions import NotAuthenticated
-from jutil.admin import admin_log, admin_obj_url, admin_obj_link, ModelAdminBase, AdminLogEntryMixin, \
-    AdminFileDownloadMixin
-from jutil.auth import require_auth, AuthUserMixin
+from jutil.admin import admin_log, admin_obj_url, admin_obj_link, ModelAdminBase, AdminLogEntryMixin
+from jutil.auth import AuthUserMixin, get_auth_user, get_auth_user_or_none
 from jutil.command import get_date_range_by_name, add_date_range_arguments, parse_date_range_arguments
 from jutil.dict import dict_to_html, choices_label
 from jutil.email import make_email_recipient_list
@@ -39,11 +38,11 @@ from jutil.testing import DefaultTestSetupMixin
 from jutil.urls import url_equals, url_mod, url_host
 from jutil.xml import xml_to_dict, dict_to_element, _xml_filter_tag_name
 from jutil.dates import add_month, per_delta, per_month, this_week, next_month, next_week, this_month, last_month, \
-    last_year, last_week, yesterday, end_of_month
+    last_year, last_week, yesterday, end_of_month, this_year, get_time_steps, TIME_STEP_DAILY
 from jutil.format import format_full_name, format_xml, format_xml_bytes, format_timedelta, dec1, dec2, dec3, dec4, dec5, \
     dec6, format_table, ucfirst_lazy, strip_media_root, get_media_full_path, camel_case_to_underscore, \
     underscore_to_camel_case, format_as_html_json
-from jutil.parse import parse_datetime, parse_bool
+from jutil.parse import parse_datetime, parse_bool, parse_datetime_or_none
 from jutil.validators import fi_payment_reference_number, se_ssn_validator, se_ssn_filter, fi_iban_validator, \
     se_iban_validator, iban_filter_readable, email_filter, iban_validator, iban_bank_info, fi_company_org_id_validator, \
     email_validator, fi_payment_reference_validator, iso_payment_reference_validator, fi_ssn_age, \
@@ -100,7 +99,7 @@ class DummyUserProfile:
     timezone = 'Europe/Helsinki'
 
 
-class MyCustomAdmin(ModelAdminBase, AdminFileDownloadMixin):
+class MyCustomAdmin(ModelAdminBase):
     max_history_length = 5
     actions = (
         dummy_admin_func_b,
@@ -110,9 +109,6 @@ class MyCustomAdmin(ModelAdminBase, AdminFileDownloadMixin):
     def get_object(self, request, obj_id):
         return self.model.objects.get(id=obj_id)
 
-    def get_object_by_filename(self, request, filename):
-        return User.objects.first()  # dummy return for test_admin_file_download_mixin
-
 
 class Tests(TestCase, DefaultTestSetupMixin):
     def setUp(self):
@@ -149,6 +145,41 @@ class Tests(TestCase, DefaultTestSetupMixin):
         except Exception:
             pass
 
+    def test_parse_datetime(self):
+        pairs = [
+            ('2016-06-12', '2016-06-12T00:00:00+00:00'),
+            ('2016-06-12T01:00:00', '2016-06-12T01:00:00+00:00'),
+            ('2016-06-12 01:00:00', '2016-06-12T01:00:00+00:00'),
+            ('2016-06-12T01:00:00+00:00', '2016-06-12T01:00:00+00:00'),
+            ('2016-06-12 01:00:00+00:00', '2016-06-12T01:00:00+00:00'),
+        ]
+        for t_str_input, t_ref_str in pairs:
+            # parse_datetime
+            t = parse_datetime(t_str_input)
+            self.assertTrue(isinstance(t, datetime))
+            assert isinstance(t, datetime)
+            self.assertEqual(t.isoformat(), t_ref_str)
+            # parse_datetime_or_none
+            t = parse_datetime_or_none(t_str_input)
+            self.assertTrue(isinstance(t, datetime))
+            assert isinstance(t, datetime)
+            self.assertEqual(t.isoformat(), t_ref_str)
+
+        invalids = [
+            '12312313ew',
+            '2016-13-05',
+        ]
+        for t_str_input in invalids:
+            # parse_datetime
+            try:
+                parse_datetime(t_str_input)
+                self.fail('{} is not valid input for parse_datetime()'.format(t_str_input))
+            except Exception:
+                pass
+            # parse_datetime_or_none
+            t = parse_datetime_or_none(t_str_input)
+            assert t is None
+
     def test_add_month(self):
         t = parse_datetime('2016-06-12T01:00:00')
         self.assertTrue(isinstance(t, datetime))
@@ -434,10 +465,12 @@ class Tests(TestCase, DefaultTestSetupMixin):
         t = datetime(2018, 5, 31)
         t_tz = pytz.utc.localize(t)
         named_ranges = [
-            ('last_month', last_month(t)),
             ('last_year', last_year(t)),
-            ('this_month', this_month(t)),
+            ('last_month', last_month(t)),
             ('last_week', last_week(t)),
+            ('this_year', this_year(t)),
+            ('this_month', this_month(t)),
+            ('this_week', this_week(t)),
             ('yesterday', yesterday(t)),
             ('today', yesterday(t + timedelta(hours=24))),
         ]
@@ -451,6 +484,22 @@ class Tests(TestCase, DefaultTestSetupMixin):
             # print('testing', name)
             self.assertEqual(get_date_range_by_name(name, t), res)
 
+    def test_time_steps(self):
+        t = parse_datetime('2020-08-24 23:28:36.503174')
+        this_week_daily = [
+            '2020-08-24T00:00:00+00:00 2020-08-25T00:00:00+00:00',
+            '2020-08-25T00:00:00+00:00 2020-08-26T00:00:00+00:00',
+            '2020-08-26T00:00:00+00:00 2020-08-27T00:00:00+00:00',
+            '2020-08-27T00:00:00+00:00 2020-08-28T00:00:00+00:00',
+            '2020-08-28T00:00:00+00:00 2020-08-29T00:00:00+00:00',
+            '2020-08-29T00:00:00+00:00 2020-08-30T00:00:00+00:00',
+            '2020-08-30T00:00:00+00:00 2020-08-31T00:00:00+00:00',
+        ]
+        ix = 0
+        for begin, end in get_time_steps(TIME_STEP_DAILY, *this_week(t)):
+            self.assertEqual('{} {}'.format(begin.isoformat(), end.isoformat()), this_week_daily[ix])
+            ix += 1
+
     def test_bank_info(self):
         ac = 'FI8847304720017517'
         inf = iban_bank_info(ac)
@@ -936,32 +985,21 @@ class Tests(TestCase, DefaultTestSetupMixin):
         assert isinstance(e, LogEntry)
         self.assertEqual(e.change_message, 'User id={}: username=test@example.com'.format(user.id))
 
-    def test_admin_file_download_mixin(self):
-        class MyModel(models.Model):
-            file = models.FileField(upload_to='uploads')
-
-        model_admin = MyCustomAdmin(MyModel, admin.site)
-        self.assertListEqual(model_admin.get_file_fields(), ['file'])
-        self.assertEqual(model_admin.single_file_field, 'file')
-        self.assertEqual(len(model_admin.get_download_urls()), 2)
-        res = model_admin.file_download_view(self.create_dummy_request(), 'requirements.txt')
-        self.assertTrue(isinstance(res, FileSystemFileResponse))
-
     def test_auth(self):
         req = self.create_dummy_request()
-        require_auth(req)  # type: ignore
+        get_auth_user(req)  # type: ignore
         req.user = None
-        self.assertIsNone(require_auth(req, exceptions=False))
+        self.assertIsNone(get_auth_user_or_none(req))
         try:
-            require_auth(req)  # type: ignore
-            self.fail('require_auth fail')
+            get_auth_user(req)  # type: ignore
+            self.fail('get_auth_user fail')
         except NotAuthenticated:
             pass
         try:
             model_admin = AuthUserMixin()
             model_admin.request = req
             user = model_admin.auth_user
-            self.fail('require_auth fail')
+            self.fail('get_auth_user fail')
         except NotAuthenticated:
             pass
 
